@@ -35,25 +35,32 @@ void Dialogs::showQuickOptionsDialog()
     {
         _quickOptionsDialog = new QDialog;
         _quickOptionsDialog->setWindowTitle("Quick options");
-        _backgroundColorButton = new QPushButton("Change background colour");
-        _foregroundColorButton = new QPushButton("Change foreground colour");
-        _fontButton = new QPushButton("Change font");
+        _backgroundColorButton = new QPushButton("Background");
+        _foregroundColorButton = new QPushButton("Foreground");
+        _fontButton = new QPushButton("Font");
+        QPushButton *aboutButton = new QPushButton("About");
+
         _alphaSlider = new QSlider(Qt::Horizontal);
         _alphaSlider->setMinimum(0);
         _alphaSlider->setMaximum(255);
+
+        QHBoxLayout *buttonsLayout = new QHBoxLayout;
+        buttonsLayout->addWidget(_backgroundColorButton);
+        buttonsLayout->addWidget(_foregroundColorButton);
+        buttonsLayout->addWidget(_fontButton);
+        QHBoxLayout *opacityLayout = new QHBoxLayout;
+        opacityLayout->addWidget(new QLabel("Opacity"));
+        opacityLayout->addWidget(_alphaSlider);
         QVBoxLayout *layout = new QVBoxLayout;
-        layout->addWidget(_backgroundColorButton);
-        layout->addWidget(_foregroundColorButton);
-        layout->addWidget(_fontButton);
-        QHBoxLayout *hLayout = new QHBoxLayout;
-        hLayout->addWidget(new QLabel("Opacity"));
-        hLayout->addWidget(_alphaSlider);
-        layout->addLayout(hLayout);
+        layout->addLayout(buttonsLayout);
+        layout->addWidget(aboutButton);
+        layout->addLayout(opacityLayout);
         _quickOptionsDialog->setLayout(layout);
 
         connect(_backgroundColorButton, SIGNAL(clicked()), this, SLOT(showBackgroundColorSelection()));
         connect(_foregroundColorButton, SIGNAL(clicked()), this, SLOT(showForegroundColorSelection()));
         connect(_fontButton, SIGNAL(clicked()), this, SLOT(showFontSelection()));
+        connect(aboutButton, SIGNAL(clicked()), this, SLOT(showAboutDialog()));
     }
 
     if (QObject::sender()->inherits("StickyNotesWidget"))
@@ -84,6 +91,10 @@ void Dialogs::showQuickOptionsDialog()
 
         isShown = false;
     }
+    else
+    {
+        qDebug() << "Problem: the sender is not a StickyNotesWidget";
+    }
 }
 
 void Dialogs::showBackgroundColorSelection()
@@ -130,7 +141,7 @@ void Dialogs::showAboutDialog()
 {
     QtHeWrapper::showHeAboutDialog(NULL,
                                    "The easiest-to-use note widget for\nyour mobile computer.",
-                                   "Timur Kristf (C) 2010, Licensed under EUPL v1.1",
+                                   "Timur Kristóf (C) 2010, Licensed under EUPL v1.1",
                                    "http://sticky-notes.garage.maemo.org/",
                                    "http://talk.maemo.org/showthread.php?t=57049",
                                    "https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=venemo%40msn%2ecom&lc=HU&item_name=Sticky%20Notes%20development%20for%20Maemo&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted",
