@@ -1,17 +1,22 @@
 
-#include "qemaemo5dynamicwidgethelper.h"
-#include "qtsingleapplication.h"
+#include <q-extras/qemaemo5dynamicwidgethelper.h>
+#include <q-extras/qtsingleapplication.h>
+#include <q-extras/qesettingsmanager.h>
 #include "stickynoteswidget.hpp"
 #include "appeventlistener.hpp"
 
 #define SETTING_SAVED_WIDGETS_COMPATIBILITY "QMaemo5DynamicWidgetHelper-SavedWidgetIds"
-#define SETTING_GREETING_MESSAGE_SHOWN "GreetingMessageShown - " + QApplication::applicationVersion()
 
 int main(int argc, char *argv[])
 {
     QApplication::setApplicationName("Sticky Notes");
     QApplication::setOrganizationName("Venemo");
-    QApplication::setApplicationVersion("0.2.2 beta");
+    // APP_VERSION and APP_BETA are defined in the .pro file
+    QApplication::setApplicationVersion(QString(APP_VERSION)
+#if APP_BETA
+        + " beta"
+#endif
+        );
 
     QtSingleApplication app(argc, argv);
     qDebug() << "Launched Sticky Notes app";
@@ -32,22 +37,44 @@ int main(int argc, char *argv[])
         }
     }
 
+    // <compatibility>
     // Ensuring that notes from previous versions of the app are displayed in this version as well.
+    // NOTE: this is for 0.1.x => 0.2.x settings format
     QSettings settings;
     if (settings.allKeys().contains(SETTING_SAVED_WIDGETS_COMPATIBILITY))
     {
         settings.setValue(SETTING_SAVED_WIDGET_IDS, settings.value(SETTING_SAVED_WIDGETS_COMPATIBILITY));
         settings.remove(SETTING_SAVED_WIDGETS_COMPATIBILITY);
     }
-    if (!settings.contains(SETTING_GREETING_MESSAGE_SHOWN) && QApplication::applicationVersion().contains("beta"))
+    // </compatibility>
+
+    // <compatibility>
+    // Ensuring that notes from previous versions of the app are displayed in this version as well.
+    // NOTE: this is for 0.2.x => 0.3.x settings format
+    QList<QString> savedWidgets(QeSettingsManager::retrieveBinary<QList<QString> >(SETTING_SAVED_WIDGET_IDS));
+    for (int i = 0; i < savedWidgets.count(); i++)
     {
-        settings.setValue(SETTING_GREETING_MESSAGE_SHOWN, true);
-        QMessageBox::information(NULL, "Sticky Notes", "Thank you for installing and testing the beta version of Sticky Notes!");
+        savedWidgets[i].remove("{").remove("}");
     }
+    QeSettingsManager::storeBinary<QList<QString> >(SETTING_SAVED_WIDGET_IDS, savedWidgets);
+    foreach (QString item, settings.allKeys())
+    {
+        if (item.contains("position") || item.contains("homescreen"))
+        {
+            settings.remove(item);
+        }
+        else if (item.contains("{") || item.contains("}"))
+        {
+            QString newItem = item;
+            newItem.remove("{").remove("}");
+            settings.setValue(newItem, settings.value(item));
+            settings.remove(item);
+        }
+    }
+    // </compatibility>
 
     app.setQuitOnLastWindowClosed(false);
-    AppEventListener listener;
-    QObject::connect(&app, SIGNAL(messageReceived(const QString&)), &listener, SLOT(receiveMessage(const QString&)));
+    AppEventListener::instance();
 
     if (app.arguments().contains("forget-widgets"))
     {
