@@ -1,7 +1,7 @@
 #include "stickynoteswidget.hpp"
 #include "ui_stickynoteswidget.h"
-#include <hildon-extras-1/hildon-extras/qt-he-wrapper.h>
 #include "dialogs.hpp"
+#include "stickynotestextedit.hpp"
 #include <QtMaemo5>
 #include <QtWebKit/QtWebKit>
 
@@ -16,6 +16,17 @@ StickyNotesWidget *StickyNotesWidget::createAndShowNew()
 {
     StickyNotesWidget *widget = new StickyNotesWidget();
     widget->show();
+    QeMaemo5DynamicWidgetHelper::globalInstance()->registerWidget(widget);
+    return widget;
+}
+
+StickyNotesWidget *StickyNotesWidget::createAndShowReadOnly(const QString &text)
+{
+    StickyNotesWidget *widget = createAndShowNew();
+    widget->_isReadOnly = true;
+    widget->ui->txtNote->setReadOnly(true);
+    widget->ui->txtNote->setFocusPolicy(Qt::NoFocus);
+    widget->ui->txtNote->setHtml(text);
     return widget;
 }
 
@@ -23,6 +34,7 @@ StickyNotesWidget::StickyNotesWidget(QWidget *parent)
     : QeMaemo5DynamicHomescreenWidget(true, parent),
     ui(new Ui::StickyNotesWidget),
     _isChanged(false),
+    _isReadOnly(false),
     _backgroundColor(QApplication::palette().window().color()),
     _timer(new QTimer(this))
 {
@@ -85,13 +97,7 @@ void StickyNotesWidget::changeEvent(QEvent *e)
 
 void StickyNotesWidget::showSettingsDialog()
 {
-    QtHeWrapper::showHeAboutDialog(NULL,
-                                   "The easiest-to-use note widget for\nyour mobile computer.",
-                                   "Timur Kristóf (C) 2010",
-                                   "http://sticky-notes.garage.maemo.org/",
-                                   "http://talk.maemo.org/showthread.php?t=57049",
-                                   "https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=venemo%40msn%2ecom&lc=HU&item_name=Sticky%20Notes%20development%20for%20Maemo&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donateCC_LG%2egif%3aNonHosted",
-                                   "sticky-notes");
+    Dialogs::instance()->showAboutDialog();
 }
 
 bool StickyNotesWidget::restoreWidgetState()
@@ -115,7 +121,7 @@ bool StickyNotesWidget::restoreWidgetState()
 
 void StickyNotesWidget::saveText()
 {
-    if (_isChanged)
+    if (_isChanged && !_isReadOnly)
     {
         _isChanged = false;
         saveSetting(SETTING_NOTES_TEXT, ui->txtNote->toHtml());
@@ -128,6 +134,11 @@ bool StickyNotesWidget::isChanged() const
     return _isChanged;
 }
 
+bool StickyNotesWidget::isReadOnly() const
+{
+    return _isReadOnly;
+}
+
 void StickyNotesWidget::setBackgroundColor(const QColor &color)
 {
     if (color.isValid())
@@ -158,17 +169,27 @@ void StickyNotesWidget::setForegroundColor(const QColor &color)
 
 void StickyNotesWidget::setFont(const QFont &newFont)
 {
+    QFont oldFont = font();
     QeMaemo5DynamicHomescreenWidget::setFont(newFont);
 
-//    //qDebug() << "\n\nbefore:" << ui->txtNote->toHtml();
+    //qDebug() << "\n\nbefore:" << ui->txtNote->toHtml();
     QString str = ui->txtNote->toHtml()
                   .replace(QRegExp("font-family:\\s?([^;]+);"), "font-family: '" + newFont.family() + "';")
                   .replace(QRegExp("font-size:\\s?([^;]+);"), "font-size: '" + QString::number(newFont.pointSize()) + "';");
-//    //qDebug() << "\n\nafter:" << str;
+    //qDebug() << "\n\nafter:" << str;
 
     ui->txtNote->setHtml(str);
     ui->txtNote->setFont(newFont);
 
+    if (newFont.bold() != oldFont.bold() || newFont.italic() != oldFont.italic())
+    {
+        QTextCursor cursor = ui->txtNote->textCursor();
+        ui->txtNote->selectAll();
+        ui->txtNote->setFontWeight(newFont.bold() ? QFont::Bold : QFont::Normal);
+        ui->txtNote->setFontItalic(newFont.italic());
+        ui->txtNote->setTextCursor(cursor);
+    }
+
     saveSetting(SETTING_NOTES_FONT, font());
 }
 
@@ -227,46 +248,6 @@ void StickyNotesWidget::setToggleButtonsState()
         ui->btnStrikeThrough->setChecked(false);
 }
 
-void StickyNotesWidget::showBackgroundColorSelection()
-{
-    static bool isShown = false;
-
-    if (!isShown)
-    {
-        isShown = true;
-        QColor newColor = QtHeWrapper::showHeSimpleColorDialog(NULL, _backgroundColor, true, "Pick a background color for this note");
-        newColor.setAlpha(_backgroundColor.alpha());
-        setBackgroundColor(newColor);
-        isShown = false;
-    }
-}
-
-void StickyNotesWidget::showForegroundColorSelection()
-{
-    static bool isShown = false;
-
-    if (!isShown)
-    {
-        isShown = true;
-        QColor newColor = QtHeWrapper::showHeSimpleColorDialog(NULL, _foregroundColor, true, "Pick a foreground color for this note");
-        setForegroundColor(newColor);
-        isShown = false;
-    }
-}
-
-void StickyNotesWidget::showFontSelection()
-{
-    static bool isShown = false;
-
-    if (!isShown)
-    {
-        isShown = true;
-        QFont newFont = QtHeWrapper::showHeFontDialog(NULL, font(), "Pick a font for this note");
-        setFont(newFont);
-        isShown = false;
-    }
-}
-
 void StickyNotesWidget::on_btnAdd_clicked()
 {
     StickyNotesWidget *newWidget = new StickyNotesWidget;
@@ -274,6 +255,7 @@ void StickyNotesWidget::on_btnAdd_clicked()
     newWidget->setForegroundColor(_foregroundColor);
     newWidget->setFont(font());
     newWidget->show();
+    QeMaemo5DynamicWidgetHelper::globalInstance()->registerWidget(newWidget);
 }
 
 void StickyNotesWidget::on_btnOptions_clicked()
@@ -283,7 +265,7 @@ void StickyNotesWidget::on_btnOptions_clicked()
 
 void StickyNotesWidget::on_btnExit_clicked()
 {
-    if (QMessageBox::Yes == QMessageBox::question(NULL, "Are you sure?", "Do you really want to close this widget?\nThe note inside it will be permamently deleted!", QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel))
+    if (ui->txtNote->toPlainText() == STICKY_NOTES_TEXT_EDIT_INITIAL_TEXT || QMessageBox::Yes == QMessageBox::question(NULL, "Are you sure?", "Do you really want to close this widget?\nThe note inside it will be permamently deleted!", QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel))
         close();
 }
 
